@@ -1,5 +1,5 @@
 from hcmioptim.ga._ga import (
     GAOptimizer, roulette_wheel_cost_selection, roulette_wheel_rank_selection,
     uniform_random_pairing_selection, tournament_selection, single_point_crossover,
-    cycle_crossover, bitset_cross_over
+    cycle_crossover, bitset_crossover
 )
